SWDEV-470698 - fix formatting, add format check workflow (#657)

This commit is contained in:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
gecommit door GitHub
bovenliggende 5840940caa
commit f7338717ae
1574 gewijzigde bestanden met toevoegingen van 162972 en 199346 verwijderingen
@@ -20,18 +20,17 @@ THE SOFTWARE.
constexpr int GLOBAL_BUF_SIZE = 2048;
__device__ float deviceGlobalFloat;
__device__ int deviceGlobalInt1;
__device__ int deviceGlobalInt2;
__device__ short deviceGlobalShort; //NOLINT
__device__ char deviceGlobalChar;
__device__ int deviceGlobalInt1;
__device__ int deviceGlobalInt2;
__device__ short deviceGlobalShort; // NOLINT
__device__ char deviceGlobalChar;
__device__ int getSquareOfGlobalFloat() {
return static_cast<int>(deviceGlobalFloat*deviceGlobalFloat);
return static_cast<int>(deviceGlobalFloat * deviceGlobalFloat);
}
extern "C" __global__ void testWeightedCopy(int* a, int* b) {
int tx = threadIdx.x;
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 +
static_cast<int>(deviceGlobalShort) + static_cast<int>(deviceGlobalChar)
+ getSquareOfGlobalFloat();
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 + static_cast<int>(deviceGlobalShort) +
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
}